import 'package:jeweled/config/default_global_settings.dart';
import 'package:jeweled/utils/tools.dart';

class GlobalSettings {
  final int colorsTheme;
  final int graphicTheme;

  GlobalSettings({
    required this.colorsTheme,
    required this.graphicTheme,
  });

  static int getColorsThemeValueFromUnsafe(int colorsTheme) {
    if (DefaultGlobalSettings.allowedColorsThemeValues.contains(colorsTheme)) {
      return colorsTheme;
    }

    return DefaultGlobalSettings.defaultColorsThemeValue;
  }

  static int getGraphicThemeValueFromUnsafe(int graphicTheme) {
    if (DefaultGlobalSettings.allowedGraphicThemeValues.contains(graphicTheme)) {
      return graphicTheme;
    }

    return DefaultGlobalSettings.defaultGraphicThemeValue;
  }

  factory GlobalSettings.createDefault() {
    return GlobalSettings(
      colorsTheme: DefaultGlobalSettings.defaultColorsThemeValue,
      graphicTheme: DefaultGlobalSettings.defaultGraphicThemeValue,
    );
  }

  void dump() {
    printlog('Settings: ');
    printlog('  colorsTheme: $colorsTheme');
    printlog('  graphicTheme: $graphicTheme');
  }

  @override
  String toString() {
    return 'GlobalSettings(${toJson()})';
  }

  Map<String, dynamic>? toJson() {
    return <String, dynamic>{
      'colorsTheme': colorsTheme,
      'graphicTheme': graphicTheme,
    };
  }
}
